==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_lb.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=lb
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// F
	'form_pet_adresse_site' => 'Adress vun ärem Site', # MODIF
	'form_pet_aucune_signature' => 'Ët entsprëcht keng Ënnerschrëft dësem Kode...', # MODIF
	'form_pet_confirmation' => 'Konfirméiert weg är Ënnerschrëft:',
	'form_pet_deja_signe' => 'Dir hutt dësen Text schon ënnerschriwen.',
	'form_pet_envoi_mail_confirmation' => 'E Konfirmatiouns-Email gouf lo grad un @email@ geschéckt. Dir musst op déi Adress surfen déi am Email steet fir är Ënnerschrëft ze bestätegen.', # MODIF
	'form_pet_mail_confirmation' => 'Bonjour,

Dir hutt gefroot fir d’Petitioun:
@titre@
ze ënnerschreiwen.

Dir hutt déi hei Informatiounen uginn:
    Numm: @nom_email@
    Site: @nom_site@ - @url_site@
    @message@

WICHTEG...
Fir är Ënnerschrëft ze validéieren, surft op dës Adress (am aneren Fall gët är Demande verworf):

    @url@


Merci fir är Participatioun
',
	'form_pet_nom_site2' => 'Numm vun ärem Site', # MODIF
	'form_pet_probleme_liens' => 'Korrigéiert äre Message a maacht d’Hypertext-Linken ewech.',
	'form_pet_probleme_technique' => 'Technësche Problem, d’Ënnerschrëften si momentan ausser Betrieb.',
	'form_pet_signature_validee' => 'Är Ënnerschrëft ass validéiert. Merci!',
	'form_pet_site_deja_enregistre' => 'Dëse Site ass schon ageschriwen',
	'form_pet_url_invalide' => 'D’URL déi der uginn hutt ass nët richteg.',
	'form_pet_votre_email' => 'Är Email-Adress',
	'form_pet_votre_nom' => 'Äre Numm oder Pseudo', # MODIF
	'form_pet_votre_site' => 'Wann dir e Web-Site hutt, da kënnt dër en hei uginn',

	// I
	'info_adresse_email' => 'EMAIL-ADRESS:',
	'info_signature_supprimee' => 'Ënnerschrëft geläscht',
	'info_signature_supprimee_erreur' => 'Fehler: dëse Läsch-Code entsprëcht kénger Ënnerschrëft', # MODIF
	'info_site_web' => 'SITE:',

	// L
	'lien_reponse_article' => 'Äntwert op den Artikel'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_lb.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=lb
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_activer_petition' => 'D’Petitioun aschalten',
	'bouton_radio_pas_petition' => 'Keng Petitioun',
	'bouton_radio_petition_activee' => 'Petitioun ageschalt',
	'bouton_radio_supprimer_petition' => 'D’Petitioun läschen',

	// F
	'form_pet_adresse_site' => 'Adress vun ärem Site', # MODIF
	'form_pet_aucune_signature' => 'Ët entsprëcht keng Ënnerschrëft dësem Kode...', # MODIF
	'form_pet_confirmation' => 'Konfirméiert weg är Ënnerschrëft:',
	'form_pet_deja_signe' => 'Dir hutt dësen Text schon ënnerschriwen.',
	'form_pet_envoi_mail_confirmation' => 'E Konfirmatiouns-Email gouf lo grad un @email@ geschéckt. Dir musst op déi Adress surfen déi am Email steet fir är Ënnerschrëft ze bestätegen.', # MODIF
	'form_pet_mail_confirmation' => 'Bonjour,

Dir hutt gefroot fir d’Petitioun:
@titre@
ze ënnerschreiwen.

Dir hutt déi hei Informatiounen uginn:
    Numm: @nom_email@
    Site: @nom_site@ - @url_site@
    @message@

WICHTEG...
Fir är Ënnerschrëft ze validéieren, surft op dës Adress (am aneren Fall gët är Demande verworf):

    @url@


Merci fir är Participatioun
',
	'form_pet_nom_site2' => 'Numm vun ärem Site', # MODIF
	'form_pet_probleme_liens' => 'Korrigéiert äre Message a maacht d’Hypertext-Linken ewech.',
	'form_pet_probleme_technique' => 'Technësche Problem, d’Ënnerschrëften si momentan ausser Betrieb.',
	'form_pet_signature_validee' => 'Är Ënnerschrëft ass validéiert. Merci!',
	'form_pet_site_deja_enregistre' => 'Dëse Site ass schon ageschriwen',
	'form_pet_url_invalide' => 'D’URL déi der uginn hutt ass nët richteg.',
	'form_pet_votre_email' => 'Är Email-Adress',
	'form_pet_votre_nom' => 'Äre Numm oder Pseudo', # MODIF
	'form_pet_votre_site' => 'Wann dir e Web-Site hutt, da kënnt dër en hei uginn',

	// I
	'info_adresse_email' => 'EMAIL-ADRESS:',
	'info_signature_supprimee' => 'Ënnerschrëft geläscht',
	'info_signature_supprimee_erreur' => 'Fehler: dëse Läsch-Code entsprëcht kénger Ënnerschrëft', # MODIF
	'info_site_web' => 'SITE:',

	// L
	'lien_reponse_article' => 'Äntwert op den Artikel'
);

?>
